*
* @20i@
* Function: rayleigh
* Description:
* Calculates the Rayleigh scattering cross sections as a function of
* wavelength. Uses the formula due to M. Nicolet, 'On the molecular 
* scattering in the terrestrial atmosphere: An empirical formula for 
* its calculation in the homosphere', Planet. Space Sci., vol. 32, 
* pp. 1467-1468, 1984.
*
* Parameters:
*    REAL(*) lambda: Wavelengths (nm) at which the Rayleigh scattering 
*                    cross section  is to be calculated. (input)
*    INTEGER n_lambda: Number of wavelengths lambda. (input)
*    INTEGER error:  Error flag. Not in use.
*    REAL(*) crs:    The Rayleigh cross section as a function of lambda.
*                    (output)
*
* Return value:
* Example:
* See @file{trans.f}.
* Files: 
* @file{consts.int}  must be present in the same directory as @file{rayleigh.f}.
* Known bugs:
* Author:  Arve Kylling    
*     
* @i20@
*
      SUBROUTINE rayleigh( crs, error, lambda, n_lambda )
*
      IMPLICIT LOGICAL (A-Z)    ! To nearly get strong typing
      INTEGER error, n_lambda
      REAL crs(*), lambda(*)
*
      REAL x, lambda_um, ray_const
      INTEGER iv
      INCLUDE 'consts.inc'
      DATA ray_const /4.02E-28/
      SAVE ray_const
*
      error = 0
      DO iv = 1, n_lambda
         lambda_um = lambda(iv) * from_nm_um        
         IF ( lambda_um .GT. 0.55 )THEN
            x = 0.04
         ELSE
            x = 0.389*lambda_um + 0.09426/lambda_um - 0.3228
         ENDIF
         crs(iv)   = ray_const / (lambda_um**(4+x))
      ENDDO
*
      RETURN
*
      END
